{% extends "bootstrap/base.html" %}
{% block html_attribs %} lang="en" translate="no"{% endblock %}
{% block head %}
  {{super()}}
  <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.0.8/css/solid.css" integrity="sha384-v2Tw72dyUXeU3y4aM2Y0tBJQkGfplr39mxZqlTBDUZAb9BGoC40+rdFCG0m10lXk" crossorigin="anonymous">
  <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.0.8/css/fontawesome.css" integrity="sha384-q3jl8XQu1OpdLgGFvNRnPdj5VIlCvgsDQTQB6owSOHWlAurxul7f+JpUOVdAiJ5P" crossorigin="anonymous">
  <link rel="stylesheet" href="/static/styles.css">
  <link rel="icon" href="data:;base64,=">
  <meta name="google" content="notranslate" />
{% endblock %}
{% block title %}{{ SITE_TITLE }}{% endblock %}

<div class="container">{% block content %}{% endblock %}</div>
