{% block footer %}
<!-- Footer -->
<hr>
<div id="footer">
  <div class="container">
    <p class="text-muted text-center">tuxput {{VERSION}}, by <a href="https://linaro.org">Linaro</a>.<br />
    </p>
  </div>
</div>
{% endblock %}
