{% extends "layout.html" %}

{% block content %}
  <div class="container">
    <div class="col-12-xs">
          This page is left intentionally empty.
          Please access via a direct link.
    </div>
  </div>
{% endblock %}
